<?php
/**
 * Amplitude Pro functions and definitions
 *
 * @package Amplitude Pro
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
function content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('the_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}
//Excerpt limit function
function custom_excerpt_length( $length ) {
	return 100;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

if ( ! function_exists( 'amplitude_pro_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function amplitude_pro_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'amplitude-pro', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_filter('widget_text', 'do_shortcode');
	add_image_size('homepage-thumb',240,145,true);	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'amplitude-pro' ),	
		'footer' => __( 'Footer Menu', 'amplitude-pro' ),		
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => '111111',
		'default-image' => get_template_directory_uri().'/images/slides/slider1.jpg',
	) );
	add_editor_style( 'editor-style.css' );
	add_editor_style( 'editor-style.css' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
endif; // amplitude_pro_setup
add_action( 'after_setup_theme', 'amplitude_pro_setup' );

function amplitude_pro_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'amplitude-pro' ),
		'description'   => __( 'Appears on blog page sidebar', 'amplitude-pro' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'amplitude-pro' ),
		'description'   => __( 'Appears on page sidebar', 'amplitude-pro' ),
		'id'            => 'sidebar-main',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );	
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'amplitude-pro' ),
		'description'   => __( 'Appears on footer', 'amplitude-pro' ),
		'id'            => 'footer-1',
		'before_widget' => '<div id="%1$s" class="widget-column-1">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'amplitude-pro' ),
		'description'   => __( 'Appears on footer', 'amplitude-pro' ),
		'id'            => 'footer-2',
		'before_widget' => '<div id="%1$s" class="widget-column-2">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'amplitude-pro' ),
		'description'   => __( 'Appears on footer', 'amplitude-pro' ),
		'id'            => 'footer-3',
		'before_widget' => '<div id="%1$s" class="widget-column-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'amplitude-pro' ),
		'description'   => __( 'Appears on footer', 'amplitude-pro' ),
		'id'            => 'footer-4',
		'before_widget' => '<div id="%1$s" class="widget-column-4">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	
	register_sidebar( array(
		'name'          => __( 'Sidebar Contact Page', 'amplitude-pro' ),
		'description'   => __( 'Appears on contact page', 'amplitude-pro' ),
		'id'            => 'sidebar-contact',
		'before_widget' => '<aside class="widget-contact %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'amplitude_pro_widgets_init' );

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once get_template_directory() . '/inc/options-framework.php';

function amplitude_pro_scripts() {	
	wp_enqueue_style( 'amplitude-pro-gfonts-lato', '//fonts.googleapis.com/css?family=Lato:400,300,300italic,400italic,700,700italic' );	

	if( of_get_option('bodyfontface',true) != '' ){
		wp_enqueue_style( 'amplitude-pro-gfonts-body', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('bodyfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if( of_get_option('logofontface',true) != '' ){
		wp_enqueue_style( 'amplitude-pro-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('navfontface', true) != '' ) {
		wp_enqueue_style( 'amplitude-pro-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('headfontface', true) != '' ) {
		wp_enqueue_style( 'amplitude-pro-gfonts-heading', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('headfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	
	if ( of_get_option('slidetitlefontface', true) != '' ) {
		wp_enqueue_style( 'amplitude-pro-gfonts-slidetitle', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('slidetitlefontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('slidedesfontface', true) != '' ) {
		wp_enqueue_style( 'amplitude-pro-gfonts-slidedes', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('slidedesfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	}	

	wp_enqueue_style( 'amplitude-pro-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'amplitude-pro-editor-style', get_template_directory_uri().'/editor-style.css' );
	wp_enqueue_style( 'amplitude-pro-base-style', get_template_directory_uri().'/css/default.css' );	
	if ( is_home() || is_front_page() ) { 
	wp_enqueue_style( 'amplitude-pro-nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'amplitude-pro-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}	

	wp_enqueue_script( 'amplitude-pro-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );	
	wp_enqueue_style( 'amplitude-pro-fontawesome-all-style', get_template_directory_uri().'/fontsawesome/css/fontawesome-all.css' );
	wp_enqueue_script( 'amplitude-pro-testimonialsminjs', get_template_directory_uri().'/testimonialsrotator/js/jquery.quovolver.min.js', array('jquery') );
	wp_enqueue_style( 'amplitude-pro-testimonialslider-style', get_template_directory_uri().'/testimonialsrotator/js/tm-rotator.css' );	
	wp_enqueue_style( 'amplitude-pro-responsive-style', get_template_directory_uri().'/css/responsive.css' );		
	wp_enqueue_style( 'amplitude-pro-owl-style', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.css' );
	wp_enqueue_script( 'amplitude-pro-owljs', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.js', array('jquery') );
	
	wp_enqueue_script( 'amplitude-pro-counterup', get_template_directory_uri().'/counter/js/jquery.counterup.min.js', array('jquery') );
	wp_enqueue_script( 'amplitude-pro-waypoints', get_template_directory_uri().'/counter/js/waypoints.min.js', array('jquery') );
	
	// mixitup script
	wp_enqueue_style( 'amplitude-pro-mixitup-style', get_template_directory_uri().'/mixitup/style-mixitup.css' );
	wp_enqueue_script( 'amplitude-pro-jquery_013-script', get_template_directory_uri() . '/mixitup/jquery_013.js', array('jquery') );
	wp_enqueue_script( 'amplitude-pro-jquery_003-script', get_template_directory_uri() . '/mixitup/jquery_003.js', array('jquery') );
	wp_enqueue_script( 'amplitude-pro-screen-script', get_template_directory_uri() . '/mixitup/screen.js', array('jquery') );
	// prettyPhoto script
	wp_enqueue_style( 'amplitude-pro-prettyphoto-style', get_template_directory_uri().'/mixitup/prettyPhotoe735.css' );
	wp_enqueue_script( 'amplitude-pro-prettyphoto-script', get_template_directory_uri() . '/mixitup/jquery.prettyPhoto5152.js', array('jquery') );
	
	//Client Logo Rotator
	wp_enqueue_style( 'amplitude-pro-flexiselcss', get_template_directory_uri().'/css/flexiselcss.css' );	
	wp_enqueue_script( 'amplitude-pro-flexisel', get_template_directory_uri() . '/js/jquery.flexisel.js', array('jquery') );
	
	
	wp_enqueue_style( 'amplitude-pro-supersized-default-theme', get_template_directory_uri()."/css/supersized.css" );	
	wp_enqueue_style( 'amplitude-pro-supersized-style', get_template_directory_uri()."/css/supersized.shutter.css" );
	wp_enqueue_script( 'amplitude-pro-supersized-easing', get_template_directory_uri() . '/js/jquery.easing.min.js', array('jquery') );	
	wp_enqueue_script( 'amplitude-pro-supersized-slider', get_template_directory_uri() . '/js/supersized.3.2.7.min.js', array('jquery') );
	wp_enqueue_script( 'amplitude-pro-supersized-shutter', get_template_directory_uri() . '/js/supersized.shutter.js', array('jquery') );

	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'amplitude_pro_scripts' );

function media_css_hook(){
	
	?>
    	
<script>
jQuery(window).load(function() {   
  jQuery('.owl-carousel').owlCarousel({
    loop:true,	
	autoplay: <?php echo of_get_option('testimonialsautoplay',true); ?>,
	autoplayTimeout: <?php echo of_get_option('testimonialsrotatingspeed',true); ?>,
    margin:20,
    nav:false,
	dots: true,
    responsive:{
        0:{
            items:1
        },
        600:{
            items:1
        },
        1000:{
            items:3
        }
    }
})
    
  });


jQuery(document).ready(function() {
  
  jQuery('.link').on('click', function(event){
    var $this = jQuery(this);
    if($this.hasClass('clicked')){
      $this.removeAttr('style').removeClass('clicked');
    } else{
      $this.css('background','#7fc242').addClass('clicked');
    }
  });
 
});
		</script>
        
        
<script type="text/javascript">	
	jQuery(window).load(function() {
		jQuery.supersized({
			// Functionality
			slideshow               :   1,			// Slideshow on/off
			autoplay				:	<?php if( of_get_option('slideauto',true) != '') { echo of_get_option('slideauto',true);} ?>, 
			start_slide             :   <?php if( of_get_option('slidestart',true) != '') { echo of_get_option('slidestart',true); } ?>,			
			stop_loop				:	<?php if( of_get_option('slidepause',true) != '') { echo of_get_option('slidepause',true);} ?>,
			random					: 	<?php if( of_get_option('sliderandom',true) != '') { echo of_get_option('sliderandom',true);} ?>,
			slide_interval          :   <?php if( of_get_option('sliderinter',true) != ''){echo of_get_option('sliderinter',true);}; ?>,		
			transition              :   <?php if( of_get_option('sliderefect',true) != ''){echo of_get_option('sliderefect',true);}; ?>, 			
			transition_speed		:	<?php if( of_get_option('slidertrans',true) != ''){echo of_get_option('slidertrans',true);}; ?>,		 
			new_window				:	1,			// Image links open in new window/tab
			pause_hover             :   0,			// Pause slideshow on hover
			keyboard_nav            :   1,			// Keyboard navigation on/off
			performance				:	1,			// 0-Normal, 1-Hybrid speed/quality, 2-Optimizes image quality, 3-Optimizes transition speed // (Only works for Firefox/IE, not Webkit)
			image_protect			:	0,			// Disables image dragging and right click with Javascript
	
			// Size & Position
			min_width		        :   0,			// Min width allowed (in pixels)
			min_height		        :   0,			// Min height allowed (in pixels)
			vertical_center         :   1,			// Vertically center background
			horizontal_center       :   1,			// Horizontally center background
			fit_always				:	0,			// Image will never exceed browser width or height (Ignores min. dimensions)
			fit_portrait         	:   1,			// Portrait images will not exceed browser height
			fit_landscape			:   0,			// Landscape images will not exceed browser width
	
			// Components 				
			slide_links				:	'blank',	// Individual links for each slide (Options: false, 'num', 'name', 'blank')
			thumb_links				:	1,			// Individual thumb links for each slide
			thumbnail_navigation    :   0,			// Thumbnail navigation
			slides 					:  	[			// Slideshow Images
											<?php
											if( is_front_page() || is_home() ){
												for ($i=1;$i<11;$i++) {
													if ( of_get_option('slide'.$i, true) != "" ) {
														$imgUrl = esc_url( of_get_option('slide'.$i, true) );
														$imgSubTitle = esc_html( of_get_option('subtitle'.$i, true) );
														$imgTitle = esc_html( of_get_option('slidetitle'.$i, true) );
														$imgDesc = esc_html( of_get_option('slidedesc'.$i, true) );
														$imgHref = esc_html( of_get_option('slideurl'.$i, true) );
														$slidebutton	= esc_html( of_get_option('slidebutton'.$i, true) );
														if( $imgUrl != '' ){
															echo '{image : \''.$imgUrl.'\', title : \''.( ($imgTitle!='') ? '<div class="slidesubtitle">' : '' ).( ($imgHref!='' && $imgSubTitle!='') ? '<span>' : '').$imgSubTitle.( ($imgHref!='' && $imgSubTitle!='') ? '</span>' : '').( ($imgSubTitle!='') ? '</div><div class="slide-title">' : '' ).( ($imgHref!='' && $imgTitle!='') ? '<span>' : '').$imgTitle.( ($imgHref!='' && $imgTitle!='') ? '</span>' : '').( ($imgTitle!='') ? '</div>' : '' ).( ($imgDesc!='') ? '<div class="slide-description">'.esc_html($imgDesc).'</div>' : '' ).( ($imgHref != '') ? '<div class="slide-readmore"><a class="morebutton" href="'.$imgHref.'">'.$slidebutton.'</a></div>' : '').'\', thumb : \''.$imgUrl.'\', url : \'\'}'.( ($i==10) ? "" : ",")."\n";
														}
													}
												}
											}else{
												$featured_as_background = esc_html( of_get_option('featured_as_background', true) );
												if( $featured_as_background != 1 && has_post_thumbnail() ) {
													$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');
													$imgUrl = $large_image_url[0];
													echo '{image : \''.$imgUrl.'\', title : \'\', thumb : \''.$imgUrl.'\', url : \'\'},'."\n";
												}else{
													
												}
											}
											?>
										],
			// Theme Options 
			progress_bar			:	1,			// Timer for each slide			
			mouse_scrub				:	0
		});
		
		// hide controller if only 1 image exist.
		var cntSlide = jQuery('ul#thumb-list li').length;
		if( cntSlide < 2 ){
			jQuery('#controls-wrapper').css('visibility','hidden');
		}
	});
</script>

<?php   
}
add_action('wp_head','media_css_hook'); 


function amplitude_pro_custom_head_codes() { 
	if ( function_exists('of_get_option') ){
		if ( of_get_option('style2', true) != '' ) {
			echo "<style>". esc_html( of_get_option('style2', true) ) ."</style>";
		}
		echo "<style>";		
		if ( of_get_option('bodyfontcolor', true) != '' ) {
			echo 'body, .contact-form-section .address,  .accordion-box .acc-content{color:'. esc_html( of_get_option('bodyfontcolor', true) ) .';}';
		}
		if( of_get_option('bodyfontface', true) != '' || of_get_option('bodyfontsize',true) != ''){
			echo "body{font-family:".of_get_option('bodyfontface')."; font-size:".of_get_option('bodyfontsize',true).";}";
		}
		if( of_get_option('logofontface',true) != '' || of_get_option('logofontcolor',true) != '' || of_get_option('logofontsize',true) != ''){
			echo ".logo h1 {font-family:".of_get_option('logofontface').";color:".of_get_option('logofontcolor',true).";font-size:".of_get_option('logofontsize',true)."}";
		}
		if( of_get_option('logotaglinecolor',true) != '' ){
			echo ".tagline{color:".of_get_option('logotaglinecolor',true).";}";
		}
		if( of_get_option('logoheight',true) != '' ){
			echo ".logo img{height:".of_get_option('logoheight',true)."px;}";
		}				
				
		if ( of_get_option('navlibdcolor', true) != '') {
			echo ".sitenav ul li, .sitenav ul li ul li{border-color:".of_get_option('navlibdcolor', true).";}";
		}
		if ( of_get_option('navfontface', true) != '' || of_get_option('navfontsize',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize',true).'}';
		}		
		if ( of_get_option('navfontcolor', true) != '' ) {
			echo '.sitenav ul li a, .sitenav ul li.current_page_item ul.sub-menu li a, .sitenav ul li.current-menu-parent ul.sub-menu li a{color:'. esc_html( of_get_option('navfontcolor', true) ) .';}';
		}
				
		if ( of_get_option('linkhovercolor', true) != '' ) {
			echo 'a:hover, .slide_toggle a:hover{color:'. esc_html( of_get_option('linkhovercolor', true) ) .';}';
		}			
		if( of_get_option('foottitlecolor', true) != '' || of_get_option('ftfontsize', true) != '' ){
			echo ".footer h5{color:".of_get_option('foottitlecolor', true)."; font-size:".of_get_option('ftfontsize', true)."; }";
		}
										
		if( of_get_option('copycolor', true) != ''){
			echo ".copyright-txt{color:".of_get_option('copycolor',true)."}";
		}
		if( of_get_option('designcolor', true) != ''){
			echo ".design-by{color:".of_get_option('designcolor',true)."}";
		}	
		
		$headerbghex = of_get_option('bgcolorforheader',true); 
		list($r,$g,$b) = sscanf($headerbghex,'#%02x%02x%02x');
		if ( of_get_option('bgcolorforheader', true) != '' ) {
			echo ".menupanelbg{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('bgcolorforheaderopacity',true).");}";
		}
		
		$headerbghex = of_get_option('bgcolorforheader',true); 
		list($r,$g,$b) = sscanf($headerbghex,'#%02x%02x%02x');
		if ( of_get_option('menudrodownopacity', true) != '' ) {
			echo ".sitenav ul li:hover > ul{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('menudrodownopacity',true).");}";
		}
		
		$logoandsocialbghex = of_get_option('logoandsocialbgcolor',true); 
		list($r,$g,$b) = sscanf($logoandsocialbghex,'#%02x%02x%02x');
		if ( of_get_option('logoandsocialbgcolor', true) != '' ) {
			echo ".social-icons, .social-icons::after, .logo, .logo::after{ background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('logoandsocialbgcoloropacity',true).");}";
		}
		
				
		$footerbghex = of_get_option('footerbgcolor',true); 
		list($r,$g,$b) = sscanf($footerbghex,'#%02x%02x%02x');
		if ( of_get_option('footerbgcolor', true) != '' || of_get_option('footdesccolor', true) != '' ) {
			echo "#footer-wrapper{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('footerbgcoloropacity',true)."); color:".of_get_option('footdesccolor', true).";}";
		}	
		
		$footercopybghex = of_get_option('footercopyrightbgcolor',true); 
		list($r,$g,$b) = sscanf($footercopybghex,'#%02x%02x%02x');
		if ( of_get_option('footercopyrightbgcolor', true) != '' ) {
			echo ".copyright-wrapper{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('footercopyrightopacity',true).");}";
		}
		
		$contentbghex = of_get_option('contentareabgcolor',true); 
		list($r,$g,$b) = sscanf($contentbghex,'#%02x%02x%02x');
		if ( of_get_option('contentareabgcolor', true) != '' ) {
			echo ".contentbox{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('contentareabgcoloropacity',true).");}";
		}
		
		$sidebarbghex = of_get_option('sidebarbgcolor',true); 
		list($r,$g,$b) = sscanf($sidebarbghex,'#%02x%02x%02x');
		if ( of_get_option('sidebarbgcolor', true) != '' ) {
			echo "#sidebar{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('sidebarbgopacity',true).");}";
		}
						
		if( of_get_option('socialfontcolor',true) != '' ){
			echo ".social-icons a{ color:".of_get_option('socialfontcolor',true).";}";
		}			
		
				
		if( of_get_option('btntxtcolor', true) != ''){
			echo ".button, #commentform input#submit, input.search-submit, .post-password-form input[type=submit], .pagination ul li span, .pagination ul li a, .headertop .right a, .wpcf7 form input[type='submit'], #sidebar .search-form input.search-submit{ color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo ".button:hover, input.search-submit:hover, .post-password-form input[type=submit]:hover, .pagination ul li .current, .pagination ul li a:hover,.headertop .right a:hover, .wpcf7 form input[type='submit']:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}		
		if( of_get_option('btntxtcolor', true) != ''){
			echo "a.morebutton{ color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "a.morebutton:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}
		
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != ''){
			echo "a.buttonstyle1{background-color:".of_get_option('btnbghvcolor',true)."; color:". of_get_option('btntxthvcolor', true) ."; }";
		}
		if( of_get_option('btntxtcolor', true) != '' ){
			echo "a.buttonstyle1:hover{ color:". esc_html( of_get_option('btntxtcolor', true) ) .";}";
		}
			
		if ( of_get_option('searchtboxbgcolor', true) != '' || of_get_option('widgetboxfontcolor', true) != '' ) {
		echo "#sidebar .search-form input.search-field{ background-color:".of_get_option('searchtboxbgcolor', true)."; color:".of_get_option('widgetboxfontcolor', true).";  }";
		}			
		if ( of_get_option('wdgttitleccolor', true) != '' ) {
			echo "h3.widget-title{ color:".of_get_option('wdgttitleccolor', true).";}";
		}			
		
		if ( of_get_option('footdesccolor', true) != '' ) {
			echo ".contactdetail a{color:".of_get_option('footdesccolor', true)."; }";
		}			
		
		if( of_get_option('sidebarliaborder', true) != '' ){
			echo "#sidebar ul li{border-color:".of_get_option('sidebarliaborder',true)."}";
		}	
		if( of_get_option('sidebarfontcolor',true) != '' ){
			echo "#sidebar ul li a{color:".of_get_option('sidebarfontcolor',true)."; }";
		}		
		
		if ( of_get_option('slidetitlefontface', true) != '' || of_get_option('slidetitlecolor', true) != '' || of_get_option('slidetitlefontsize', true) != '') {
		echo "div.slide-title{ font-family:".of_get_option('slidetitlefontface', true)."; color:".of_get_option('slidetitlecolor', true)."; font-size:".of_get_option('slidetitlefontsize', true).";}";
		}
		
		if ( of_get_option('slidetitlefontface', true) != '' || of_get_option('slidesubtitlecolor', true) != '' || of_get_option('slidesubtitlefontsize', true) != '') {
		echo ".slidesubtitle{ font-family:".of_get_option('slidetitlefontface', true)."; color:".of_get_option('slidesubtitlecolor', true)."; font-size:".of_get_option('slidesubtitlefontsize', true).";}";
		}
		
		if ( of_get_option('slidetitlecolor', true) != '' ) {
		echo "div.slide-title a{ color:".of_get_option('slidetitlecolor', true).";}";
		}
		
		if ( of_get_option('slidedesfontface', true) != '' || of_get_option('slidedesccolor', true) != '' || of_get_option('slidedescfontsize', true) != '') {
		echo ".slide-description{font-family:".of_get_option('slidedesfontface', true)."; color:".of_get_option('slidedesccolor', true)."; font-size:".of_get_option('slidedescfontsize', true).";}";
		}
			
		if ( of_get_option('copylinkshover', true) != '' ) {
		echo ".copyright-wrapper a:hover{ color: ".of_get_option('copylinkshover', true)."; }";
		}				
		
/* Heading */
		if( of_get_option('headfontface', true) != '' ){
			echo "h1,h2,h3,h4,h5,h6{ font-family:".of_get_option('headfontface',true)."; }";
		}		
		if ( of_get_option('h1fontsize', true) != '' || of_get_option('h1fontcolor', true) != '' ) {
			echo "h1{ font-size:".of_get_option('h1fontsize', true)."; color:".of_get_option('h1fontcolor', true).";}";
		}
		if ( of_get_option('h2fontsize', true) != '' || of_get_option('h2fontcolor', true) != '' ) {
			echo "h2{ font-size:".of_get_option('h2fontsize', true)."; color:".of_get_option('h2fontcolor', true).";}";
		}		
		if ( of_get_option('h3fontsize', true) != '' || of_get_option('h3fontcolor', true) != '' ) {
			echo "h3{ font-size:".of_get_option('h3fontsize', true)."; color:".of_get_option('h3fontcolor', true).";}";
		}		
		if ( of_get_option('h4fontsize', true) != '' || of_get_option('h4fontcolor', true) != '' ) {
			echo "h4{ font-size:".of_get_option('h4fontsize', true)."; color:".of_get_option('h4fontcolor', true).";}";
		}		
		if ( of_get_option('h5fontsize', true) != '' || of_get_option('h5fontcolor', true) != '' ) {
			echo "h5{font-size:".of_get_option('h5fontsize', true)."; color:".of_get_option('h5fontcolor', true).";}";
		}		
		if ( of_get_option('h6fontsize', true) != '' || of_get_option('h6fontcolor', true) != '' ) {
			echo "h6{ font-size:".of_get_option('h6fontsize', true)."; color:".of_get_option('h6fontcolor', true).";}";
		}
/* Custom editable */			
		
		$slidercaptionhex = of_get_option('slidercaptionbgcolor',true); 
		list($r,$g,$b) = sscanf($slidercaptionhex,'#%02x%02x%02x');
		if ( of_get_option('slidercaptionbgcolor', true) != '' ) {
			echo "#slidecaption{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('slidercaptionbgcoloropacity',true).");}";
		}
				
		if ( of_get_option('galleryfilter', true) != '' || of_get_option('galleryfiltercolor', true) != '' || of_get_option('galleryfilterbdr', true) != '' ) {
			echo "ul.portfoliofilter li a{ background-color:".of_get_option('galleryfilter', true).";  color:".of_get_option('galleryfiltercolor', true)."; border-color:".of_get_option('galleryfilterbdr', true).";}";
		}
		
		if ( of_get_option('galleryfiltercolorhv', true) != '' ) {
			echo "ul.portfoliofilter li a.selected, ul.portfoliofilter li a:hover,ul.portfoliofilter li:hover a{ color:".of_get_option('galleryfiltercolorhv', true)."; }";
		}		
		
		if ( of_get_option('gallerytitlecolorhv', true) != '' ) {
			echo ".holderwrap h5{ color:".of_get_option('gallerytitlecolorhv', true)."; }";
		}
		if ( of_get_option('gallerytitlecolorhv', true) != '' ) {
			echo ".holderwrap h5::after{ background-color:".of_get_option('gallerytitlecolorhv', true)."; }";
		}
			
		//Team Member CSS
				
		if ( of_get_option('teambxbgcolor', true) != '' || of_get_option('teambxfontcolor', true) != '' ) {
			echo ".teammember-content{ background-color:".of_get_option('teambxbgcolor', true)."; color:".of_get_option('teambxfontcolor', true).";}";
		}		
		
		if ( of_get_option('teamtitlecolor', true) != '' ) {
			echo ".teammember-content h4{ color:".of_get_option('teamtitlecolor', true).";}";
		}
				
		//Testimonials CSS
		
		if ( of_get_option('testidotsbgcolor', true) != '' ) {
			echo ".owl-controls .owl-dot{ background-color:".of_get_option('testidotsbgcolor', true)."; }";
		}		
		
		if ( of_get_option('testimonialdescriptioncolor', true) != '' ) {
			echo "#clienttestiminials .item{ color:".of_get_option('testimonialdescriptioncolor', true)."; }";
		}
				
		if ( of_get_option('testimonialtitlecolor', true) != '' ) {
			echo "#clienttestiminials h6 a{ color:".of_get_option('testimonialtitlecolor', true)."; }";
		}
				
		if ( of_get_option('footerpoststitlecolor', true) != '' ) {
			echo "ul.recent-post li a{ color:".of_get_option('footerpoststitlecolor', true)."; }";
		}
		
		//Color scheme for one click background color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".themefeatures .one_third:hover,
			.button, 
			#commentform input#submit, 
			input.search-submit, 
			.post-password-form input[type='submit'], 			
			.pagination ul li span, 
			.pagination ul li a, 
			.headertop .right a, 			
			#sidebar .search-form input.search-submit,
			.nivo-controlNav a.active,
			ul.portfoliofilter li a.selected, 
			ul.portfoliofilter li a:hover,
			ul.portfoliofilter li:hover a,
			.woocommerce ul.products li.product .product-thumb,
			.woocommerce span.onsale,
			.holderwrap,
			#clienttestiminials .tmnlThumb,			
			.owl-controls .owl-dot.active,
			.clientlgo,			
			.button:hover, 			
			input.search-submit:hover, 
			.post-password-form input[type=submit]:hover, 			
			.pagination ul li .current, 
			.pagination ul li a:hover,			
			.wpcf7 form input[type='submit'],			
			.teammember-list .thumnailbx,
			a.morebutton,
			a.buttonstyle1:hover,			
			.news-thumb .postdt,
			.news-box .news-thumb
			{ background-color:".of_get_option('colorscheme', true)."; }";
		}
		
		
		
		//Color scheme for one click font color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".sitenav ul li a:hover, 
			.sitenav ul li.current_page_item a, 
			.sitenav ul li.current_page_item ul li a:hover,
			.sitenav ul li.current-menu-parent a, 
			.sitenav ul li:hover,
			.sitenav ul li.current_page_item ul.sub-menu li a:hover, 
			.sitenav ul li.current-menu-parent ul.sub-menu li a:hover,
			.sitenav ul li.current-menu-parent ul.sub-menu li.current_page_item a,
			.sitenav ul li:hover,			
			.social-icons a:hover,
			.woocommerce ul.products li.product:hover h2,
			.cntbutton,
			.logo a:hover,
			.woocommerce ul.products li.product a.add_to_cart_button:hover,
			.woocommerce div.product p.price,
			#clienttestiminials h6 a:hover,	
			.tmnllisting h5 a:hover,		
			.contactdetail a:hover, 			
			.footer ul li a:hover, 
			.footer ul li.current_page_item a, 
			div.recent-post a:hover,			
			.copyright-wrapper a,
			.member-social-icon a:hover,
			a, .post-tags, 
			p.read-more a:hover, 
			.post-title a:hover,	
			.woocommerce-message::before,		
			.slide_toggle a, 
			.blog-post-repeat .postmeta a:hover,
			.news-box h6 a:hover,
			#sidebar ul li a:hover,
			.teammember-content span,
			#section6 h3 span,
			#clienttestiminials i,			
			.mycounterbox .mycountervalue
			{ color:".of_get_option('colorscheme', true)."; }";
		}
				
		
		//Color scheme for one click border color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo "ul.portfoliofilter li a.selected, 
			ul.portfoliofilter li a:hover,
			#clienttestiminials .item,
			p.read-more a:hover, 
			.blogpostdate,			
			ul.portfoliofilter li:hover a{ border-color:".of_get_option('colorscheme', true)."; }";
		}
		
		//Color scheme for one click border color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".triangle-bottomleft{  border-bottom:50px solid ".of_get_option('colorscheme', true)."; }";
		}
		
		//Color scheme for one click border color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".woocommerce-message{  border-top-color:".of_get_option('colorscheme', true)."; }";
		}
		
		
		echo "</style>";
	}
}
add_action('wp_head', 'amplitude_pro_custom_head_codes');


function amplitude_pro_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';

function amplitude_pro_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}
// get slug by id
function amplitude_pro_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}