<?php
/**
 * Kids Campus Pro  functions and definitions
 *
 * @package Kids Campus Pro 
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
function content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('the_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}
//Excerpt limit function
function custom_excerpt_length( $length ) {
	return 100;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

if ( ! function_exists( 'kids_campus_pro_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function kids_campus_pro_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'kids-campus-pro', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_filter('widget_text', 'do_shortcode');
	add_image_size('homepage-thumb',240,145,true);	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'kids-campus-pro' ),
		'footer' => __( 'Footer Menu', 'kids-campus-pro' ),		
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
endif; // kids_campus_pro_setup
add_action( 'after_setup_theme', 'kids_campus_pro_setup' );

function kids_campus_pro_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'kids-campus-pro' ),
		'description'   => __( 'Appears on blog page sidebar', 'kids-campus-pro' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'kids-campus-pro' ),
		'description'   => __( 'Appears on page sidebar', 'kids-campus-pro' ),
		'id'            => 'sidebar-main',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );	
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'kids-campus-pro' ),
		'description'   => __( 'Appears on footer', 'kids-campus-pro' ),
		'id'            => 'footer-1',
		'before_widget' => '<div id="%1$s" class="widget-column-1">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'kids-campus-pro' ),
		'description'   => __( 'Appears on footer', 'kids-campus-pro' ),
		'id'            => 'footer-2',
		'before_widget' => '<div id="%1$s" class="widget-column-2">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'kids-campus-pro' ),
		'description'   => __( 'Appears on footer', 'kids-campus-pro' ),
		'id'            => 'footer-3',
		'before_widget' => '<div id="%1$s" class="widget-column-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'kids-campus-pro' ),
		'description'   => __( 'Appears on footer', 'kids-campus-pro' ),
		'id'            => 'footer-4',
		'before_widget' => '<div id="%1$s" class="widget-column-4">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

}
add_action( 'widgets_init', 'kids_campus_pro_widgets_init' );

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once get_template_directory() . '/inc/options-framework.php';

function kids_campus_pro_scripts() {	
	wp_enqueue_style( 'kids-campus-pro-gfonts-opensans', '//fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i' );
  	wp_enqueue_style( 'kids-campus-pro-gfonts-roboto', '//fonts.googleapis.com/css?family=Roboto:300,400,600,900' );
	wp_enqueue_style( 'kids-campus-pro-gfonts-amatic', '//fonts.googleapis.com/css?family=Amatic+SC:400,700&display=swap' );	
	wp_enqueue_style( 'kids-campus-pro-gfonts-patrick', '//fonts.googleapis.com/css?family=Patrick+Hand&display=swap' );

	if( of_get_option('bodyfontface',true) != '' ){
		wp_enqueue_style( 'kids-campus-pro-gfonts-body', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('bodyfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if( of_get_option('logofontface',true) != '' ){
		wp_enqueue_style( 'kids-campus-pro-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('navfontface', true) != '' ) {
		wp_enqueue_style( 'kids-campus-pro-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('headfontface', true) != '' ) {
		wp_enqueue_style( 'kids-campus-pro-gfonts-heading', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('headfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('sectiontitlefontface', true) != '' ) {
		wp_enqueue_style( 'kids-campus-pro-gfonts-sectiontitle', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('sectiontitlefontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('slidetitlefontface', true) != '' ) {
		wp_enqueue_style( 'kids-campus-pro-gfonts-slidetitle', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('slidetitlefontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('slidedesfontface', true) != '' ) {
		wp_enqueue_style( 'kids-campus-pro-gfonts-slidedes', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('slidedesfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	}	

	wp_enqueue_style( 'kids-campus-pro-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'kids-campus-pro-editor-style', get_template_directory_uri().'/editor-style.css' );
	wp_enqueue_style( 'kids-campus-pro-base-style', get_template_directory_uri().'/css/default.css' );	
	if ( is_home() || is_front_page() ) { 
	wp_enqueue_style( 'kids-campus-pro-nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'kids-campus-pro-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}	

	wp_enqueue_script( 'kids-campus-pro-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );		
	wp_enqueue_style( 'kids-campus-pro-fontawesome-all-style', get_template_directory_uri().'/fontsawesome/css/fontawesome-all.css' );
	
				
	wp_enqueue_style( 'kids-campus-pro-animation', get_template_directory_uri().'/css/animation.css' );
	wp_enqueue_style( 'kids-campus-pro-hover', get_template_directory_uri().'/css/hover.css' );
	wp_enqueue_style( 'kids-campus-pro-hover-min', get_template_directory_uri().'/css/hover-min.css' );
	wp_enqueue_script( 'kids-campus-pro-testimonialsminjs', get_template_directory_uri().'/testimonialsrotator/js/jquery.quovolver.min.js', array('jquery') );
	wp_enqueue_style( 'kids-campus-pro-testimonialslider-style', get_template_directory_uri().'/testimonialsrotator/js/tm-rotator.css' );	
	wp_enqueue_style( 'kids-campus-pro-responsive-style', get_template_directory_uri().'/css/responsive.css' );		
	wp_enqueue_style( 'kids-campus-pro-owl-style', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.css' );
	wp_enqueue_script( 'kids-campus-pro-owljs', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.js', array('jquery') );
	
	wp_enqueue_script( 'kids-campus-pro-counterup', get_template_directory_uri().'/counter/js/jquery.counterup.min.js', array('jquery') );
	wp_enqueue_script( 'kids-campus-pro-waypoints', get_template_directory_uri().'/counter/js/waypoints.min.js', array('jquery') );
	
	
	// mixitup script
	wp_enqueue_style( 'kids-campus-pro-mixitup-style', get_template_directory_uri().'/mixitup/style-mixitup.css' );
	wp_enqueue_script( 'kids-campus-pro-jquery_013-script', get_template_directory_uri() . '/mixitup/jquery_013.js', array('jquery') );
	wp_enqueue_script( 'kids-campus-pro-jquery_003-script', get_template_directory_uri() . '/mixitup/jquery_003.js', array('jquery') );
	wp_enqueue_script( 'kids-campus-pro-screen-script', get_template_directory_uri() . '/mixitup/screen.js', array('jquery') );
	// prettyPhoto script
	wp_enqueue_style( 'kids-campus-pro-prettyphoto-style', get_template_directory_uri().'/mixitup/prettyPhotoe735.css' );
	wp_enqueue_script( 'kids-campus-pro-prettyphoto-script', get_template_directory_uri() . '/mixitup/jquery.prettyPhoto5152.js', array('jquery') );
	
	//Client Logo Rotator
	wp_enqueue_style( 'kids-campus-pro-flexiselcss', get_template_directory_uri().'/css/flexiselcss.css' );	
	wp_enqueue_script( 'kids-campus-pro-flexisel', get_template_directory_uri() . '/js/jquery.flexisel.js', array('jquery') );
	
	//Popup Video
	wp_enqueue_style( 'kids-campus-pro-youtube-popup', get_template_directory_uri().'/popupvideo/grt-youtube-popup.css' );	
	wp_enqueue_script( 'kids-campus-pro-youtube-popup', get_template_directory_uri() . '/popupvideo/grt-youtube-popup.js', array('jquery') );
	
	if( of_get_option('scrollanimation',true) != true) {
		wp_enqueue_style( 'kids-campus-pro-animation-style', get_template_directory_uri().'/css/animation-style.css' );
		wp_enqueue_script( 'kids-campus-pro-custom-animation', get_template_directory_uri() . '/js/custom-animation.js', array('jquery') );	
	}
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'kids_campus_pro_scripts' );

function media_css_hook(){
	
	?>
    	
    	<script>
		jQuery(window).bind('scroll', function() {
	var wwd = jQuery(window).width();
	if( wwd > 939 ){
		var navHeight = jQuery( window ).height() - 500;
		<?php if( of_get_option('headstick',true) != '') { ?>
		if (jQuery(window).scrollTop() > navHeight) {
			jQuery(".site-header").addClass('fixed');
		}else {
			jQuery(".site-header").removeClass('fixed');
		}
		<?php } ?>
	}
});		

<?php if ( is_home() || is_front_page() ) { ?>
					
		jQuery(window).load(function() {
        jQuery('#slider').nivoSlider({
        	effect:'<?php echo of_get_option('slideefect',true); ?>', //sliceDown, sliceDownLeft, sliceUp, sliceUpLeft, sliceUpDown, sliceUpDownLeft, fold, fade, random, slideInRight, slideInLeft, boxRandom, boxRain, boxRainReverse, boxRainGrow, boxRainGrowReverse
		  	animSpeed: <?php echo of_get_option('slideanim',true); ?>,
			pauseTime: <?php echo of_get_option('slidepause',true); ?>,
			directionNav: <?php echo of_get_option('slidenav',true); ?>,
			controlNav: <?php echo of_get_option('slidepage',true); ?>,
			pauseOnHover: <?php echo of_get_option('slidepausehover',true); ?>,
    });
});

<?php } ?>

jQuery(window).load(function() {   
  jQuery('.owl-carousel').owlCarousel({
    loop:true,	
	autoplay: <?php echo of_get_option('testimonialsautoplay',true); ?>,
	autoplayTimeout: <?php echo of_get_option('testimonialsrotatingspeed',true); ?>,
    margin:0,
    nav:false,
	dots: true,
    responsive:{
        0:{
            items:1
        },
        600:{
            items:1
        },
        1000:{
            items:1
        }
    }
})
    
  });


jQuery(document).ready(function() {
  
  jQuery('.link').on('click', function(event){
    var $this = jQuery(this);
    if($this.hasClass('clicked')){
      $this.removeAttr('style').removeClass('clicked');
    } else{
      $this.css('background','#7fc242').addClass('clicked');
    }
  });
 
});
		</script>
<?php   
}
add_action('wp_head','media_css_hook'); 


function kids_campus_pro_custom_head_codes() { 
	if ( function_exists('of_get_option') ){
		if ( of_get_option('style2', true) != '' ) {
			echo "<style>". esc_html( of_get_option('style2', true) ) ."</style>";
		}
		echo "<style>";		
		if ( of_get_option('bodyfontcolor', true) != '' ) {
			echo 'body, .contact-form-section .address,  .accordion-box .acc-content{color:'. esc_html( of_get_option('bodyfontcolor', true) ) .';}';
		}
		if( of_get_option('bodyfontface', true) != '' || of_get_option('bodyfontsize',true) != ''){
			echo "body{font-family:".of_get_option('bodyfontface')."; font-size:".of_get_option('bodyfontsize',true).";}";
		}
		if( of_get_option('logofontface',true) != '' || of_get_option('logofontcolor',true) != '' || of_get_option('logofontsize',true) != ''){
			echo ".logo h1 {font-family:".of_get_option('logofontface').";color:".of_get_option('logofontcolor',true).";font-size:".of_get_option('logofontsize',true)."}";
		}
		
		if( of_get_option('logotaglinecolor',true) != '' ){
			echo ".tagline{color:".of_get_option('logotaglinecolor',true).";}";
		}
		if( of_get_option('logoheight',true) != '' ){
			echo ".logo img{height:".of_get_option('logoheight',true)."px;}";
		}		
		
		if ( of_get_option('headermenubgcolor', true) != '') {
			echo ".header-nav{ background:".of_get_option('headermenubgcolor',true)."; }";
		}		
		
		if ( of_get_option('navfontface', true) != '' || of_get_option('navfontsize',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize',true).'}';
		}		
		if ( of_get_option('navfontcolor', true) != '' || of_get_option('navfontactivecolor', true) != '' ) {
			echo '.sitenav ul li a, .sitenav ul li.current_page_parent li a{color:'. esc_html( of_get_option('navfontcolor', true) ) .';}';
			echo '.sitenav ul li a:hover, .sitenav ul li ul li a:hover, .sitenav ul li.current_page_item a, .sitenav ul li.current_page_parent a, .sitenav ul li.current_page_parent li.current_page_item a{color:'. esc_html( of_get_option('navfontactivecolor', true) ) .';}';
		}		
			 
		if( of_get_option('sectiontitlefontface',true) != '' || of_get_option('sectitlesize',true) != '' || of_get_option('sectitlecolor',true) != '' ){
			echo "h2.section_title, h3.section_title{ font-family:".of_get_option('sectiontitlefontface',true)."; font-size:".of_get_option('sectitlesize',true)."; color:".of_get_option('sectitlecolor',true)."; }";
		}	
				
		if ( of_get_option('linkhovercolor', true) != '' ) {
			echo 'a:hover, .slide_toggle a:hover{color:'. esc_html( of_get_option('linkhovercolor', true) ) .';}';
		}			
		if( of_get_option('foottitlecolor', true) != '' || of_get_option('ftfontsize', true) != '' ){
			echo ".footer h5{color:".of_get_option('foottitlecolor', true)."; font-size:".of_get_option('ftfontsize', true)."; }";
		}
		
		if( of_get_option('designcolor', true) != ''){
			echo ".design-by, .copyright-txt{color:".of_get_option('designcolor',true)."}";
		}		

		if ( of_get_option('headertopfontcolor', true) != '') {
			echo ".logonavigation .left, .logonavigation .right{ color:".of_get_option('headertopfontcolor',true)."; }";
		}
						
		if( of_get_option('socialfontcolor',true) != '' ){
			echo ".logonavigation .social-icons a{ color:".of_get_option('socialfontcolor',true).";}";
		}			
		
				
		if( of_get_option('btntxtcolor', true) != ''){
			echo ".button, #commentform input#submit, input.search-submit, .post-password-form input[type=submit], p.read-more a, .pagination ul li span, .pagination ul li a, .headertop .right a, .wpcf7 form input[type='submit'], #sidebar .search-form input.search-submit{ color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "#commentform input#submit:hover, input.search-submit:hover, .post-password-form input[type=submit]:hover, p.read-more a:hover, .pagination ul li .current, .pagination ul li a:hover,.headertop .right a:hover, .wpcf7 form input[type='submit']:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}		
		if( of_get_option('btntxtcolor', true) != ''){
			echo "a.morebutton{ color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "a.morebutton:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}

		if ( of_get_option('ourfeaturedsbgcolor', true) != '' ) {
			echo ".ourfeaturedcontentbg{background-color:".of_get_option('ourfeaturedsbgcolor', true).";}";
		}
		if ( of_get_option('ourfeaturesbg', true) != '') {
			echo "#ourfeatured{background:#f1f1f1 url(".of_get_option('ourfeaturesbg', true).") no-repeat top center;}";
		}	
			
		if ( of_get_option('widgetboxbgcolor', true) != '' || of_get_option('widgetboxfontcolor', true) != '' ) {
		echo "aside.widget{ background-color:".of_get_option('widgetboxbgcolor', true)."; color:".of_get_option('widgetboxfontcolor', true).";  }";
		}			
		if ( of_get_option('wdgttitleccolor', true) != '' ) {
			echo "h3.widget-title{ color:".of_get_option('wdgttitleccolor', true).";}";
		}				
		if ( of_get_option('footerbgcolor', true) != '' || of_get_option('footdesccolor', true) != '' ) {
			echo "#footer-wrapper{background-color:".of_get_option('footerbgcolor', true)."; color:".of_get_option('footdesccolor', true).";}";
			echo ".footer ul li a, .contactdetail h6{color:".of_get_option('footdesccolor', true).";}";
			echo ".footerbottom .pattern{fill:".of_get_option('footerbgcolor', true).";}";
		}
		if ( of_get_option('copybgcolor', true) != '' ) {
			echo ".copyright-wrapper{background-color:".of_get_option('copybgcolor', true)."; }";
		}
		if ( of_get_option('footdesccolor', true) != '' ) {
			echo ".contactdetail a{color:".of_get_option('footdesccolor', true)."; }";
		}			
				
		if( of_get_option('sldpagebg',true) != ''){
			echo ".nivo-controlNav a{background-color:".of_get_option('sldpagebg',true)."}";
		}
		
		if( of_get_option('sidebarliaborder', true) != '' ){
			echo "#sidebar ul li{border-color:".of_get_option('sidebarliaborder',true)."}";
		}	
		if( of_get_option('sidebarfontcolor',true) != '' ){
			echo "#sidebar ul li a{color:".of_get_option('sidebarfontcolor',true)."; }";
		}		
		
		if ( of_get_option('slidetitlefontface', true) != '' || of_get_option('slidetitlecolor', true) != '' || of_get_option('slidetitlefontsize', true) != '') {
		echo ".nivo-caption h2{ font-family:".of_get_option('slidetitlefontface', true)."; color:".of_get_option('slidetitlecolor', true)."; font-size:".of_get_option('slidetitlefontsize', true).";}";
		}
		
		if ( of_get_option('slidedesfontface', true) != '' || of_get_option('slidedesccolor', true) != '' || of_get_option('slidedescfontsize', true) != '') {
		echo ".nivo-caption p{font-family:".of_get_option('slidedesfontface', true)."; color:".of_get_option('slidedesccolor', true)."; font-size:".of_get_option('slidedescfontsize', true).";}";
		}
					
		if ( of_get_option('copylinkshover', true) != '' ) {
		echo ".copyright-wrapper a:hover{ color: ".of_get_option('copylinkshover', true)."; }";
		}	
		
		if ( of_get_option('togglemenucolor', true) != '' ) {
		echo ".toggle a{ color:".of_get_option('togglemenucolor', true)."; }";
		}
		
		
		
/* Heading */
		if( of_get_option('headfontface', true) != '' ){
			echo "h1, h2, h3, h4, h5, h6{ font-family:".of_get_option('headfontface',true)."; }";
		}		
		if ( of_get_option('h1fontsize', true) != '' || of_get_option('h1fontcolor', true) != '' ) {
			echo "h1{ font-size:".of_get_option('h1fontsize', true)."; color:".of_get_option('h1fontcolor', true).";}";
		}
		if ( of_get_option('h2fontsize', true) != '' || of_get_option('h2fontcolor', true) != '' ) {
			echo "h2{ font-size:".of_get_option('h2fontsize', true)."; color:".of_get_option('h2fontcolor', true).";}";
		}		
		if ( of_get_option('h3fontsize', true) != '' || of_get_option('h3fontcolor', true) != '' ) {
			echo "h3{ font-size:".of_get_option('h3fontsize', true)."; color:".of_get_option('h3fontcolor', true).";}";
		}		
		if ( of_get_option('h4fontsize', true) != '' || of_get_option('h4fontcolor', true) != '' ) {
			echo "h4{ font-size:".of_get_option('h4fontsize', true)."; color:".of_get_option('h4fontcolor', true).";}";
		}		
		if ( of_get_option('h5fontsize', true) != '' || of_get_option('h5fontcolor', true) != '' ) {
			echo "h5{font-size:".of_get_option('h5fontsize', true)."; color:".of_get_option('h5fontcolor', true).";}";
		}		
		if ( of_get_option('h6fontsize', true) != '' || of_get_option('h6fontcolor', true) != '' ) {
			echo "h6{ font-size:".of_get_option('h6fontsize', true)."; color:".of_get_option('h6fontcolor', true).";}";
		}					
			
		if ( of_get_option('footsocialcolor', true) != '' ) {
			echo "#footer-wrapper .social-icons a{ color:".of_get_option('footsocialcolor', true)."; }";
		}		
		
		/*$slidercaphex = of_get_option('slidercaptionbg',true); 
		list($r,$g,$b) = sscanf($slidercaphex,'#%02x%02x%02x');
		if ( of_get_option('sldarrowbg', true) != '' ) {
			echo ".nivo-caption{background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('captionopacity',true).");}";
		}*/				
		
		if ( of_get_option('galleryfiltercolor', true) != '' ) {
			echo "ul.portfoliofilter li a{ color:".of_get_option('galleryfiltercolor', true)."; border-color:".of_get_option('galleryfiltercolor', true).";  }";
		}			
		if ( of_get_option('sectionpagebgcolor', true) != '' ) {
			echo "section#pagearea{background-color:".of_get_option('sectionpagebgcolor', true).";}";
			echo ".sectiontop .pattern, .sectionbottom .pattern{fill:".of_get_option('sectionpagebgcolor', true).";}";
		}
		if ( of_get_option('hometopfourbxtitlecolor', true) != '' ) {
			echo ".fourpagebox h3{ color:".of_get_option('hometopfourbxtitlecolor', true)."; }";
		}
		
		// EVENTS
		if ( of_get_option('eventstitlecolor', true) != '' || of_get_option('eventscolor', true) != '' ) {
			echo "#events-carousel .eventscontent h3{ color:".of_get_option('eventstitlecolor', true)."; }";
			echo "#events-carousel .eventscontent, #events-carousel .eventscontent .events-read h6{ color:".of_get_option('eventscolor', true)."; }";
		}		
		//Testimonials CSS			
		if ( of_get_option('testidotsbgcolor', true) != '' ) {
			echo ".owl-controls .owl-dot.active{ background:".of_get_option('testidotsbgcolor', true).";}";
		}		
		if ( of_get_option('testimonialbgcolor', true) != '' ) {
			echo "#clienttestiminials .testimonials-bg{background:".of_get_option('testimonialbgcolor', true).";}";
			echo "#clienttestiminials .testimonials-bg:after{border-top-color:".of_get_option('testimonialbgcolor', true).";}";
		}	
		if ( of_get_option('testimonialdescriptioncolor', true) != '' ) {
			echo "#clienttestiminials .testimonials-bg p{ color:".of_get_option('testimonialdescriptioncolor', true)."; }";
		}			
				
		if ( of_get_option('footerpoststitlecolor', true) != '' ) {
			echo "ul.recent-post li h6 a{ color:".of_get_option('footerpoststitlecolor', true)."; }";
		}
		
		if ( of_get_option('hdrbfcolormobileview', true) != '' ) {
			echo "@media screen and (max-width: 980px){ .site-header{ background-color:".of_get_option('hdrbfcolormobileview', true)."; } }";
		}	
		
		//Color scheme for one click background color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo "
			.sitenav ul li a:hover, 
			.sitenav ul li.current_page_item a, 
			.sitenav ul li.current_page_parent a, 
			.sitenav ul li ul li.current_page_item a,
			.sitenav ul li:hover > ul,
			#commentform input#submit, 
			.button,
			input.search-submit, 
			.post-password-form input[type='submit'], 
			p.read-more a,
			.header-top .social-icons a:hover, 
			.pagination ul li span, 
			.pagination ul li a, 
			.headertop .right a, 
			#sidebar .search-form input.search-submit,
			.nivo-controlNav a.active,			
			.holderwrap,
			#commentform input#submit:hover, 
			input.search-submit:hover, 
			.post-password-form input[type=submit]:hover, 
			p.read-more a:hover, 
			.pagination ul li .current, 
			.pagination ul li a:hover,
			.headertop .right a:hover, 
			.wpcf7 form input[type='submit']:hover,					
			#footer-wrapper .social-icons a:hover,
			.toggle a,
			a.morebutton,						
			a.joinusstyle1,			
			.newspostdate,
			.blogrightsidebar .post-thumb,
			.bloggridlayout .post-thumb,			
			.woocommerce ul.products li.product a.add_to_cart_button:hover,
			.nbs-flexisel-nav-left:hover, .nbs-flexisel-nav-right:hover,		
			.woocommerce span.onsale,			
			.pagereadmore,
			.news_left_side .postdt,
			.moreicon .i, .news-title, .donatenow, a.ourfeaturedReadMore, .causes-col a.read-more, .news_imgbox, .newsletter-form input[type=submit], .woocommerce ul.products li.product:hover i:after, .woocommerce ul.products li.product:hover .product-shadow:after, .newsletter-form i, .ourfeatured-thumb, .news_imgbox span.postdt, .tabstitle, .tabs-wrapper ul.tabs li a.selected, .tabs-wrapper ul.tabs li:hover a, .flexiselDemo3 .clientlogo, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce span.onsale, .col-md-4 .icon-img{background-color:".of_get_option('colorscheme', true)."; }";
			
			echo ".homecontact:after{ border-left-color:".of_get_option('colorscheme', true)."; }";
			echo ".footer .button, h3.widget-title::after{ border-color:".of_get_option('colorscheme', true)."; }";
		}
		
				
		//Color scheme for one click font color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo "a, .fourpagebox:hover h3,		
			#section3 h3 span,
			.offcontnt .pricedv,			
			.contactdetail a:hover, 
			.footer h5 span, 
			.footer ul li a:hover, 
			.footer ul li.current_page_item a, 
			div.recent-post a:hover,		
			.copyright-wrapper a,				
			.slide_toggle a,			
			#sidebar ul li a:hover,
			h3.post-title a:hover,
			.welcome_titlecolumn h3 span,		
			.woocommerce table.shop_table th, 
			.woocommerce-page table.shop_table th,
			#clienttestiminials h6 a,			
			ul.portfoliofilter li a.selected, 
			ul.portfoliofilter li a:hover,
			ul.portfoliofilter li:hover a,
			.welcome_contentcolumn h3 span,
			.mycounterbox .counter,
			.woocommerce ul.products li.product h2:hover,
			#section8 h3 span,
			.ftr_textlogo h2 span,
			.woocommerce div.product p.price, 
			.woocommerce div.product span.price, .header-top .social-icons a:hover, .header-infobox i, .cuase-raised h5 span, .circle-title, .tabs-wrapper .tab-content ul li:before, .logonavigation .social-icons a:hover{ color:".of_get_option('colorscheme', true)."; }";
		}
			
		//Color scheme for one click border color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".welcomebx h3::after,			
			#section7 .subtitle,
			ul.portfoliofilter li a.selected,				
			.nivo-controlNav a.active::after,
			#section7 .owl-prev:hover, #section7 .owl-next:hover,
			ul.portfoliofilter li:hover a, .circle-left{ border-color:".of_get_option('colorscheme', true)."; }";
		}
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".contact-image{box-shadow: 15px 15px 0 ".of_get_option('colorscheme', true)."; }";
		}
		//Color scheme for one click border color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".newspostdate::after, .col-md-4:hover .icon-img:after{ border-top-color:".of_get_option('colorscheme', true)."; }";
		}
		
		// Second Color scheme for hole site
		if ( of_get_option('colorscheme_hover', true) != '' ) {
			echo " 
			.sitenav ul li ul.sub-menu li a:hover,
			.sitenav ul li ul.sub-menu li.current_page_item a, .button:hover, .ourfeaturedReadMore:hover, .causes-col a.read-more:hover, #section6 .custombtn a:hover, #section6 .custombtn a:hover:after, #section6 .custombtn a:hover:before, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .col-md-4 .icon-img, .owl-controls .owl-dot, .teammember-list .thumnailbx, #events-carousel .eventsthumb, .button i, .wpcf7 form input[type='submit']{background-color:".of_get_option('colorscheme_hover', true)."; }";
		}
		
		if ( of_get_option('colorscheme_hover', true) != '' ) {
			echo ".owl-controls .owl-dot, .teammember-list .thumnailbx-border{ border-color:".of_get_option('colorscheme_hover', true)."; }";
			echo ".teammember-list h3.title{color:".of_get_option('colorscheme_hover', true)."; }";
			echo ".videobox{box-shadow:10px 10px 0 ".of_get_option('colorscheme_hover', true)."; }";
		}
		
		
		echo "</style>";
	}
}
add_action('wp_head', 'kids_campus_pro_custom_head_codes');


//pagination
function kids_campus_pro_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}


//pagination
function kids_campus_pro_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';
